;; Generated package description from cm-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "cm-mode" "1.10.0.20260518.192037" "Minor mode for CriticMarkup" '((emacs "25.1") (cl-lib "0.5")) :commit "a5816175548a821bf62d374b40d6974e4956c44b" :url "https://elpa.gnu.org/packages/cm-mode.html" :authors '(("Joost Kremers" . "joostkremers@fastmail.fm")) :maintainer '("Joost Kremers" . "joostkremers@fastmail.fm") :keywords '("text" "markdown"))
